@@ -31,6 +31,7 @@
 #include <QTextStream>
 #include <QTextDocument>
 
+
 LanMorseForm::LanMorseForm(
   MainWindow *mw)
   : QWidget(mw),
@@ -46,13 +47,14 @@ LanMorseForm::LanMorseForm(
   setWindowFlags(windowFlags() | Qt::Window);
 
   setupSOSCode();
-
-  QSettings settings("pietrzak.org", "Lanterne");
+  setupECode();
 
   ui->dotDurationSpinBox->setMinimum(10);
   ui->dotDurationSpinBox->setMaximum(1000);
   ui->dotDurationSpinBox->setValue(100);
 
+  QSettings settings("pietrzak.org", "Lanterne");
+
   if (settings.contains("CurrentDotDuration"))
   {
     int cdd = settings.value("CurrentDotDuration").toInt();
@@ -62,6 +64,13 @@ LanMorseForm::LanMorseForm(
       ui->dotDurationSpinBox->setValue(cdd);
     }
   }
+
+  if (settings.contains("RunMorseContinuously"))
+  {
+    bool rmc = settings.value("RunMorseContinuously").toBool();
+
+    ui->repeatCheckBox->setChecked(rmc);
+  }
 }
 
 
@@ -73,6 +82,10 @@ LanMorseForm::~LanMorseForm()
     "CurrentDotDuration",
     ui->dotDurationSpinBox->value());
 
+  settings.setValue(
+    "RunMorseContinuously",
+    ui->repeatCheckBox->isChecked());
+
   if (timer) delete timer;
 
   delete ui;
@@ -99,6 +112,26 @@ void LanMorseForm::startSOS()
 }
 
 
+void LanMorseForm::startE()
+{
+  if (timer)
+  {
+    delete timer;
+    timer = 0;
+
+    if (morseRunning)
+    {
+      morsePaused = true;
+    }
+  }
+
+  eCodePosition = eCodeBits.begin();
+  timer = new QTimer(this);
+  connect (timer, SIGNAL(timeout()), this, SLOT(runECode()));
+  timer->start(ui->dotDurationSpinBox->value());
+}
+
+
 void LanMorseForm::stopTimer()
 {
   if (timer)
@@ -204,20 +237,33 @@ void LanMorseForm::on_selectTextFileButton_clicked()
 }
 
 
+void LanMorseForm::on_repeatCheckBox_toggled(bool checked)
+{
+  runMorseContinuously = checked;
+}
+
+
 void LanMorseForm::runMorseCode()
 {
   if (morseCodePosition == morseCodeBits.end())
   {
-    if (timer)
+    if (runMorseContinuously)
     {
-      delete timer;
-      timer = 0;
+      morseCodePosition = morseCodeBits.begin();
     }
+    else
+    {
+      if (timer)
+      {
+        delete timer;
+        timer = 0;
+      }
 
-    morseRunning = false;
-    morsePaused = false;
+      morseRunning = false;
+      morsePaused = false;
 
-    return;
+      return;
+    }
   }
 
   if (*morseCodePosition)
@@ -253,6 +299,26 @@ void LanMorseForm::runSOSCode()
 }
 
 
+void LanMorseForm::runECode()
+{
+  if (eCodePosition == eCodeBits.end())
+  {
+    eCodePosition = eCodeBits.begin();
+  }
+
+  if (*eCodePosition)
+  {
+    mainWindow->turnTorchOn();
+  }
+  else
+  {
+    mainWindow->turnTorchOff();
+  }
+
+  ++eCodePosition;
+}
+
+
 //
 // This method will convert the desired text into morse code bits:
 //
@@ -529,6 +595,14 @@ void LanMorseForm::setupSOSCode()
 }
 
 
+void LanMorseForm::setupECode()
+{
+  // We'll do an "E" (single dot), followed by 7-dot word space:
+  eCodeBits.push_back(true);
+  pushBits(eCodeBits, false, 8);
+}
+
+
 void LanMorseForm::pushBits(
   LanBoolList &bits,
   bool value,
